@@ -8,7 +8,7 @@
 */
 
 static char *version=
-"@(#)Splitvt 1.6.1   1/8/95  -Sam Lantinga   (slouken@cs.ucdavis.edu)\n";
+"@(#)Splitvt 1.6.3  12/12/95  -Sam Lantinga   (slouken@cs.ucdavis.edu)\n";
 
 #include	<sys/types.h>
 #include	<sys/time.h>
@@ -85,6 +85,7 @@ char *argv;
 	fprintf(stderr, "\t\t\t\tin the top window.  This number will\n");
 	fprintf(stderr, "\t\t\t\tbe modified if the screen isn't big\n");
 	fprintf(stderr, "\t\t\t\tenough to handle the full size.\n\n");
+	fprintf(stderr, "\t-t title\t\tSets the xterm title bar to 'title'\n");
 	fprintf(stderr, "\t-upper command\t\tRuns 'command' in the upper window\n");
 	fprintf(stderr, "\t-lower command\t\tRuns 'command' in the lower window\n");
 	fprintf(stderr, "\t-login\t\t\tRuns programs as if they were login shells\n");
@@ -106,11 +107,13 @@ char *argv[];
 
 	int i, len, maxfds, numready;
 	char buffer[BUFSIZ], *ptr;
+	char *xterm_title=NULL;
 	struct timeval tv, *tvptr;
 	fd_set read_mask;
 	static struct passwd pwdata;	/* Our passwd entry */
 
 	struct event X_event;
+	int on_separator=0;
 
 #ifdef NEED_INET_H
         /* There is a bug in the Wallabong Group's implementation
@@ -138,7 +141,7 @@ char *argv[];
 		splitvtrc();
 
 	/* Parse command line options */
-	while ( (i=getopt(argc, argv, "n:u:l:r:s:vh")) != EOF )
+	while ( (i=getopt(argc, argv, "n:u:l:r:s:t:vh")) != EOF )
 	{
 		switch (i)
 		{
@@ -169,6 +172,8 @@ char *argv[];
 				  break;
 			case 's': UU_lines=atoi(optarg);
 				  break;
+			case 't': xterm_title=optarg;
+				  break;
 			case 'v': printf("%s", version+4);
 				  exit(0);
 				  break;
@@ -207,12 +212,14 @@ char *argv[];
 #ifdef X_SUPPORT
 #ifdef XTITLE
 	/* Make the title bar the version string, strip extraneous info. */
-	strcpy(buffer, version+4);
-	buffer[39]='\0';
-	(void) event_init(stdin, stdout, buffer);
-#else
-	(void) event_init(stdin, stdout, NULL);
+	if ( xterm_title == NULL ) {
+		strcpy(buffer, version+4);
+		buffer[39]='\0';
+		xterm_title=buffer;
+	}
 #endif
+	/* This must be called before pty_open() */
+	(void) event_init(stdin, stdout, xterm_title);
 #endif /* X_SUPPORT */
 	selection[0]='\0';
 
@@ -379,19 +386,27 @@ char *argv[];
 					/* Work only on button press */
 					if ( ! BUTTON_ISSET(X_event, RELEASE) ) {
 					/* Mouse click in which winow? */
-						if ( X_event.x > WU_lines ) { 
-							if ( bottomok )
-								thisfd=bottomfd;
-							SET_WIN();
-						}
-						else if (X_event.x < WU_lines)
+						if ( X_event.x <= WU_lines )
 						{ 
 							if ( topok )
 								thisfd=topfd;
 							SET_WIN();
-						}
-						if ( BUTTON_ISSET(X_event, BUTTON_2) )
+						} else 
+						if ( X_event.x > (WU_lines+1) )
+						{ 
+							if ( bottomok )
+								thisfd=bottomfd;
+							SET_WIN();
+						} else
+							on_separator=X_event.x;
+
+						if ( BUTTON_ISSET(X_event, BUTTON_2) ) {
+							strcpy(selection, vt_getselbuf());
 							write(thisfd, selection, strlen(selection));
+						}
+					} else if ( on_separator ) {
+						move_bar(X_event.x-on_separator);
+						on_separator=0;
 					}
 #ifdef REPORT_SELECTION
 					if ( (X_event.button_state&SELECTED) == SELECTED ) {
@@ -400,11 +415,11 @@ char *argv[];
 								X_event.selection.end_row, 
 								X_event.selection.begin_col, 
 								X_event.selection.end_col); 
+						vt_setselbuf(selection);
 					}
 #endif
-				} else {
+				} else if ( buffer[0] )
 					do_input(buffer[0]);
-				}
 			} while (terminal_input);
 		}
 
@@ -521,10 +536,12 @@ promptch:
 				  break;
 			/* Copy selection */
 			case 'c': vt_getsel(CUR_WIN(), selection, BUFSIZ);
+				  vt_setselbuf(selection);
 				  reset_bar(1);
 				  break;
 			/* Paste selection */
-			case 'p': write(thisfd, selection, strlen(selection));
+			case 'p': strcpy(selection, vt_getselbuf());
+				  write(thisfd, selection, strlen(selection));
 				  break;
 			/* Lock the screen */
 			case 'x': vt_info("Enter password: ");
@@ -663,15 +680,19 @@ int howfar;
 {
 	int tmp_uulines;
 
+	/* Don't redraw the screen if there is no movement on the bar */
+	if ( ! howfar )
+		return;
+
 	tmp_uulines=UU_lines;
 	UU_lines=WU_lines;
 	UU_lines += howfar;	/* Positive to go down, negative to go up */
 	init_vt100();		/* Reset the windows to the new size */
 
 	/* Tell the running processes about the size change */
-	if ( topfd )
+	if ( topok )
 		pty_setwin(topfd, UPPER);
-	if ( bottomfd )
+	if ( bottomok )
 		pty_setwin(bottomfd, LOWER);
 	UU_lines=tmp_uulines;
 }	
@@ -693,9 +714,9 @@ int sig;
 		finish(0);
 	} else
 		SET_WIN();
-	if ( topfd )
+	if ( topok )
 		pty_setwin(topfd, UPPER);
-	if ( bottomfd )
+	if ( bottomok )
 		pty_setwin(bottomfd, LOWER);
 }
 
